# FPNResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**fpn_reference_number** | **str** |  | 
**fpn_offence_type** | [**OffenceCodeResponse**](OffenceCodeResponse.md) |  | 
**fpn_offence_type_string** | **str** |  | 
**issue_date_time** | **datetime** |  | 
**fpn_status** | [**FPNStatusResponse**](FPNStatusResponse.md) |  | 
**fpn_status_string** | **str** |  | 
**status_changed_date** | **datetime** |  | 
**location** | **str** |  | 
**offence_date** | **datetime** |  | 
**offence_details** | **str** |  | 
**authorised_officer** | **str** |  | 
**officer_contact_details** | **str** |  | 
**officer_address** | **str** |  | [optional] 
**representations_contact** | **str** |  | [optional] 
**representations_contact_address** | **str** |  | [optional] 
**payment_methods** | [**list[PaymentMethodResponse]**](PaymentMethodResponse.md) |  | [optional] 
**payment_methods_string** | **list[str]** |  | [optional] 
**work_reference_number** | **str** |  | 
**promoter_organisation** | **str** |  | 
**ha_organisation** | **str** |  | 
**files** | [**list[FileSummaryResponse]**](FileSummaryResponse.md) |  | [optional] 
**permit_reference_number** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

